@@ -738,8 +738,8 @@ couchdb_document_is_contact (CouchdbDocument *document)
 {
 	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), FALSE);
 
-	return !g_ascii_strcasecmp (couchdb_document_get_record_type (document),
-				    COUCHDB_RECORD_TYPE_CONTACT);
+	return !g_strcmp0 (couchdb_document_get_record_type (document),
+			   COUCHDB_RECORD_TYPE_CONTACT);
 }
 
 /**
@@ -756,6 +756,6 @@ couchdb_document_is_task (CouchdbDocument *document)
 {
 	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), FALSE);
 
-	return !g_ascii_strcasecmp (couchdb_document_get_record_type (document),
-				    COUCHDB_RECORD_TYPE_TASK);
+	return !g_strcmp0 (couchdb_document_get_record_type (document),
+			   COUCHDB_RECORD_TYPE_TASK);
 }
