@@ -70,11 +70,11 @@ static void debug_message (const gchar *log_domain,
 			   const gchar *message, gpointer user_data);
 #endif
 
-static gboolean _session_authenticate(SoupSession *session,
-				      SoupMessage *msg,
-				      SoupAuth *auth,
-				      gboolean retrying,
-				      gpointer couchdb);
+static gboolean _session_authenticate (SoupSession *session,
+				       SoupMessage *msg,
+				       SoupAuth *auth,
+				       gboolean retrying,
+				       gpointer couchdb);
 
 
 static void
@@ -186,7 +186,7 @@ couchdb_session_init (CouchdbSession *session)
 	if (session->priv->uri == NULL)
 		session->priv->uri = g_strdup("http://127.0.0.1:5984");
 
-	session->priv->http_session = soup_session_sync_new_with_options (
+	session->priv->http_session = soup_session_async_new_with_options (
 		SOUP_SESSION_ADD_FEATURE_BY_TYPE, SOUP_TYPE_GNOME_FEATURES_2_26,
                 NULL);
 
@@ -557,9 +557,9 @@ couchdb_session_is_authentication_enabled (CouchdbSession *session)
 }
 
 static gboolean
-_session_authenticate(SoupSession *http_session, SoupMessage *msg,
-		      SoupAuth *auth, gboolean retrying,
-		      gpointer callback_data)
+_session_authenticate (SoupSession *http_session, SoupMessage *msg,
+		       SoupAuth *auth, gboolean retrying,
+		       gpointer callback_data)
 {
 	CouchdbSession *session;
 
@@ -772,7 +772,7 @@ debug_message (const gchar *log_domain, GLogLevelFlags log_level,
 {
 	const gchar* couchdb_env_debug_messages;
 
-	couchdb_env_debug_messages = g_getenv(COUCHDB_ENV_DEBUG_MESSAGES);
+	couchdb_env_debug_messages = g_getenv (COUCHDB_ENV_DEBUG_MESSAGES);
 	if (couchdb_env_debug_messages != NULL) {
 		g_print ("%s-DEBUG: %s\n", log_domain, message);
 	}
@@ -792,7 +792,7 @@ debug_message (const gchar *log_domain, GLogLevelFlags log_level,
  *
  * If @continous is FALSE, the replication will happen once, but if set to TRUE,
  * CouchDB will listen to all changes made to the source database, and automatically
- * replicate over any new docs as the come into the source to the target.
+ * replicate over any new docs as they come into the source to the target.
  *
  * Return value: TRUE if successful, FALSE otherwise, in which case the @error
  * parameter will be set to contain information about the error.
